summaryrefslogtreecommitdiffstats
path: root/kmail/kmsearchpatternedit.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kmail/kmsearchpatternedit.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/kmsearchpatternedit.h')
-rw-r--r--kmail/kmsearchpatternedit.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmsearchpatternedit.h b/kmail/kmsearchpatternedit.h
index 307a7ae2..e42ae080 100644
--- a/kmail/kmsearchpatternedit.h
+++ b/kmail/kmsearchpatternedit.h
@@ -44,7 +44,7 @@ class KMSearchRuleWidget : public TQWidget
public:
/** Constructor. You can give a KMSearchRule as parameter, which will
be used to initialize the widget. */
- KMSearchRuleWidget( TQWidget* tqparent=0, KMSearchRule* aRule=0, const char* name=0, bool headersOnly = false, bool absoluteDates = false );
+ KMSearchRuleWidget( TQWidget* parent=0, KMSearchRule* aRule=0, const char* name=0, bool headersOnly = false, bool absoluteDates = false );
enum { Message, Body, AnyHeader, Recipients, Size, AgeInDays, tqStatus,
Subject, From, To, CC, ReplyTo, Organization };
@@ -111,7 +111,7 @@ class KMSearchRuleWidgetLister : public KWidgetLister
friend class ::KMSearchPatternEdit;
public:
- KMSearchRuleWidgetLister( TQWidget *tqparent=0, const char* name=0, bool headersOnly = false, bool absoluteDates = false );
+ KMSearchRuleWidgetLister( TQWidget *parent=0, const char* name=0, bool headersOnly = false, bool absoluteDates = false );
virtual ~KMSearchRuleWidgetLister();
@@ -123,7 +123,7 @@ public slots:
protected:
virtual void clearWidget( TQWidget *aWidget );
- virtual TQWidget* createWidget( TQWidget *tqparent );
+ virtual TQWidget* createWidget( TQWidget *parent );
private:
void regenerateRuleListFromWidgets();
@@ -169,12 +169,12 @@ class KMSearchPatternEdit : public TQGroupBox {
Q_OBJECT
TQ_OBJECT
public:
/** Constructor. The tqparent and name parameters are passed to the underlying
TQGroupBox, as usual. */
- KMSearchPatternEdit(TQWidget *tqparent=0, const char *name=0, bool headersOnly = false, bool absoluteDates = false);
+ KMSearchPatternEdit(TQWidget *parent=0, const char *name=0, bool headersOnly = false, bool absoluteDates = false);
/** Constructor. This one allows you to set a title different from
i18n("Search Criteria"). */
- KMSearchPatternEdit(const TQString & title, TQWidget *tqparent=0, const char *name=0, bool headersOnly = false, bool absoluteDates = false);
+ KMSearchPatternEdit(const TQString & title, TQWidget *parent=0, const char *name=0, bool headersOnly = false, bool absoluteDates = false);
~KMSearchPatternEdit();
/** Set the search pattern. Rules are inserted regardless of the
@@ -169,12 +169,12 @@ class KMSearchPatternEdit : public TQGroupBox {
TQ_OBJECT
public:
- /** Constructor. The tqparent and name parameters are passed to the underlying
+ /** Constructor. The parent and name parameters are passed to the underlying
TQGroupBox, as usual. */